/*
 * Copyright 2013 Google LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.google.auto.factory;

import com.google.inject.AbstractModule;

public class GuiceModule extends AbstractModule {
  @Override
  protected void configure() {
    bind(Dependency.class).to(DependencyImpl.class);
    bind(Dependency.class).annotatedWith(Qualifier.class).to(QualifiedDependencyImpl.class);
    bind(Integer.class).toInstance(1);
    bind(Integer.class).annotatedWith(Qualifier.class).toInstance(2);
    bind(Number.class).toInstance(3);
  }
}
